میانگین بازده صندوق روزانه

##### شرکت مدیریت فناوری بورس تهران

###### مرکز پردازش اطلاعات مالی ایران

## میانگین بازده صندوق روزانه

#### در این گزارش سر جمع خالص ارزش دارایی‌ها و میانگین بازده کل صندوق‌ها برای آخرین روز دریافت اطلاعات نمایش داده می‌شود. دارایی‌های نقد شامل وجه نقد ، سپرده بانکی و اوراق مشارکت می‌باشد. اطلاعات زیر بدون در نظر گرفتن صندوق‌های بازارگردان می‌باشد.

نوع صندوق | خالص ارزش دارایی صندوق(میلیارد ریال) | %میانگین دارایی‌های نقدی | میانگین بازدهی هفته(%) | میانگین بازدهی ماه(%) | میانگین بازدهی 3 ماهه(%) | میانگین بازدهی 6 ماهه(%) | میانگین بازدهی سال(%) | میانگین بازدهی از آغاز فعالیت(%)
--- | --- | --- | --- | --- | --- | --- | --- | ---
در سهام | 532222 | 18.86 | -5.17 | -7.29 | -3.89 | 8.66 | 28.40 | 3168.95
با در آمد ثابت | 3794154 | 82.74 | 0.16 | 1.34 | 4.76 | 9.58 | 17.73 | 165.31
مختلط | 22811 | 41.86 | -3.04 | -3.44 | 1.87 | 10.91 | 7.55 | 1741.13
تمام صندوق ها | 4759596 | 40.14 | -2.98 | -4.37 | -0.66 | 8.42 | 5.58 | 1606.03